#
# spec file for package xfce4-genmon-plugin
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define xfce_version 4.16.0
%define plugin genmon
Name:           xfce4-%{plugin}-plugin
Version:        4.3.0
Release:        bp156.2.6.1
Summary:        Generic Monitoring Plugin for the Xfce Panel
License:        LGPL-2.1-or-later
Group:          System/GUI/XFCE
URL:            https://docs.xfce.org/panel-plugins/xfce4-genmon-plugin
Source0:        https://archive.xfce.org/src/panel-plugins/%{name}/4.3/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  gettext >= 0.19.8
BuildRequires:  meson >= 0.54.0
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(glib-2.0) >= 2.50.0
BuildRequires:  pkgconfig(gtk+-3.0) >= 3.22.0
BuildRequires:  pkgconfig(libxfce4panel-2.0) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfce4ui-2) >= %{xfce_version}
BuildRequires:  pkgconfig(libxfconf-0) >= %{xfce_version}
# Still uses exo-open till Xfce 4.21
Requires:       exo-tools
Requires:       xfce4-panel >= %{xfce_version}
Recommends:     %{name}-lang = %{version}
# package was renamed in 2019 after Leap 15.1
Provides:       xfce4-panel-plugin-%{plugin} = %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin} < %{version}-%{release}
Obsoletes:      xfce4-panel-plugin-%{plugin}-debuginfo

%description
The Generic Monitor plugin is intended for custom monitoring tasks and
periodically spawns a given application, captures its output and displays the
result in form of an image, a bar, a button and a personalized tooltip in the
panel.

%package lang
Summary:        Translations for package %{name}
Group:          System/Localization
Requires:       %{name} = %{version}
Supplements:    %{name}
Provides:       %{name}-lang-all = %{version}
# package was renamed in 2019 after Leap 15.1
Obsoletes:      xfce4-panel-plugin-%{plugin}-lang < %{version}-%{release}
Provides:       xfce4-panel-plugin-%{plugin}-lang = %{version}-%{release}
BuildArch:      noarch

%description lang
Provides translations for the "%{name}" package.

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install

rm -f %{buildroot}%{_libdir}/xfce4/panel/plugins/libgenmon.la

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,tl_PH,ur_PK}

%find_lang %{name} %{name}.lang %{?no_lang_C}

%fdupes %{buildroot}%{_datadir}

%files
%doc AUTHORS NEWS README
%license COPYING
%{_libdir}/xfce4/panel/plugins/libgenmon.so
%{_datadir}/icons/hicolor/*/apps/org.xfce.genmon.*
%{_datadir}/xfce4/panel/plugins/genmon.desktop
%dir %{_datadir}/xfce4/genmon
%dir %{_datadir}/xfce4/genmon/scripts
%{_datadir}/xfce4/genmon/scripts/*

%files lang -f %{name}.lang

%changelog
* Tue Jun  3 2025 Maurizio Galli <maurizio.galli@suse.com>
- Update to version 4.3.0
  - Update README after switchover to meson
  - autotools-build: Explicitly require glib, gtk3
  - meson-build: Use shared_module()
  - Replace deprecated exo with libxfce4ui 4.21.0
  - build: Automate copyright year management
  - Add meson build
  - autotools-build: Explicitly require libxfce4util
  - Fix libxfce4panel include
  - Translation Updates
* Fri Dec  6 2024 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.2.1
  * Update copyright year
  * build: Bump dependency versions and fix deprecation warnings
  * I18n: Update po/LINGUAS list
  * build: Use XDT_VERSION_INIT and get rid of configure.ac.in
  * build: clang: Fix -Wsometimes-uninitialized
  * build: Get rid of intltool
  * Install scripts dir when building
  * Fix copyright string
  * Update copyright year and info
  * Fix type in xfconf migration script
  * Translation Updates
- Add installed scripts to the rpm filelist.
* Mon Apr 17 2023 Manfred Hollstein <manfred.h@gmx.net>
- Update to version 4.2.0
  * Add shell script to migrate settings to xfconf
  * Fix GDK_Critical
  * Fixed deskbar support. Issue #8
  * Add Update Now menu option to right-click menu
  * build: Add GLib requirement
  * build: Fix autotools warnings
  * Use "logo-icon-name" instead of "logo" in about dialog
  * ***Migrate settings to xfconf
  * Remove unused variable
  * Fix intltool lock file bug in make distcheck
  * Remove closing of standard file descriptors in the child process
  * Update COPYING
  * Add <css> tag support
  * fixed .genmon_label and -gtk-icon transform bugs
  * Fix code indentation and readalility
  * Add support for single and multi-row panel layout options
  * Added support for <css></css> XML tag. Changed default
    progressbar width to 4px
  * automake: Modernize following other projects
  * autoconf: Some updates
  * Update `.gitignore`
  * Add missing comments to code functions
  * Fix indentation
  * Translation updates
- Remove _service file
* Mon Jan 25 2021 Marcel Kuehlhorn <tux93@opensuse.org>
- Update to version 4.1.1
  * Update configure.ac.in syntax
  * Add help button to configuration dialog
  * Add filechooser dialog option to select command
  * Add new genmon icon
  * Remove GSourceFunc casts
  * update prototype of UpdateConf
  * Set labels to center justify by default
  * Translation updates
* Wed Dec 23 2020 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.1.0
  - Add basic GitLab pipeline
  - Updated README file
  - Add DBG anchors
  - Add <icon> amd <iconclick> elements
  - Make Save translatable
  - Fix config values sometimes going to default
  - Fix label sometimes re-appearing
  - Enable multi-row support
  - Remove unused variables and code
  - Fix indentation
  - Catch some edge cases
  - Set tmp variable default values
  - Fix period spinner display when cancelled
  - Fix label toggle display when cancelled
  - Fix font display when cancelled
  - Support new libxfce4ui API
  - Change close to save
  - Closing config window cancels changes
  - Change layout of config dialog
  - Make tooltips translatable
  - Update support URLs to docs.xfce.org
  - Allow compilation with panel 4.15
  - Replace deprecated xfce_create_panel_button
  - Translation Updates
* Fri Aug 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Fixed sources in spec file
* Mon Aug 12 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Update to version 4.0.2
  - Change font to use pt instead of px to match system font setting
  - Simplify and standardize spacing
  - Adjust tooltip such that period is shown as float (2) number
  - Translation updates
* Tue Jul 16 2019 Maurizio Galli <maurizio.galli@gmail.com>
- Package renamed to follow upstream name xfce4-foo-plugin
- Use lang subpackage for manual edits instead of %%lang_package macro
- Cleaned up spec file
- Added bcond for git master builds
- Only add NEWS and omi Changelog
* Fri Nov 10 2017 seife+obs@b1-systems.com
- update to version 4.0.1
  - Allow pango markup in tooltip as well
  - Fix progressbar wrong direction
* Wed Jul 19 2017 seife+obs@b1-systems.com
- update to version 4.0.0
  - Port to Gtk3
  - Fix font styling to work with Gtk 3.22
  - Add support for "genmon" in 'xfce4-panel --plugin-event' (bxo#10734)
  - Fix default tooltip does not work (bxo#11284)
  - Add <txtclick> functionality (bxo#3437)
- packaging: do not package ChangeLog, NEWS is good enough
* Sat May 12 2012 gber@opensuse.org
- update to version 3.4.0
  - port from libxfcegui4 to libxfce4ui
  - install as a shared library rather than an executable
  - no longer uses troublesome fixed-length text buffers
  - bug fixes
* Fri Apr 20 2012 gber@opensuse.org
- corrected license
- added documentation files
* Tue Apr 17 2012 gber@opensuse.org
- corrected source URL
* Tue Apr  3 2012 gber@opensuse.org
- specfile cleanup
- correct dependencies
- split off -lang subpackage
* Thu Jan  5 2012 gber@opensuse.org
- updated to version 3.3.1
  - change icon to "utilities-system-monitor"
  - fix problems when changing panel orientation
  - fix timer not started at startup (bnc#737801)
  - remove obsolete samples.txt
- dropped obsolete
  xfce4-panel-plugin-genmon-initialize-timer-on-startup.patch
* Tue Dec 20 2011 gber@opensuse.org
- added xfce4-panel-plugin-genmon-initialize-timer-on-startup.patch
  which fixes a bug introduced in 3.3.0 where the display timer
  was not initialized on startup (bnc#737801)
- fix missing icon
- remove unncessary xdt-autogen run
* Fri May 27 2011 coolo@novell.com
- use suse_update_desktop_file to translate
* Wed Mar 23 2011 gber@opensuse.org
- update to version 3.3.0
  + Support for xfce 4.8
  + Translated to 29 languages
  + Introduces new markup for colored and styled text
  + Various small bug fixes
  + Build and package fixes
- dropped obsolete
  xfce4-panel-plugin-genmon-3.2-fix-build-with-4.7.patch,
  xfce4-panel-plugin-genmon-3.2-prevent-zombies.patch, and
  xfce4-panel-plugin-genmon-3.2-close-unused-pipes.patch
* Wed Mar  9 2011 gber@opensuse.org
- new package (split off from xfce4-panel-plugins)
